package com.brainysoftware.batik;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JPanel;

import org.apache.batik.swing.JSVGCanvas;
import org.apache.batik.transcoder.Transcoder;
import org.apache.batik.transcoder.TranscoderException;
import org.apache.batik.transcoder.TranscoderInput;
import org.apache.batik.transcoder.TranscoderOutput;
import org.apache.batik.transcoder.image.PNGTranscoder;

public class SVGFileViewerPlus extends JFrame implements ActionListener {
	static final long serialVersionUID = 222222;

	// A button to open the dialog
	private JButton btnOpenFile, btnSaveFile;
	
	// The URI of the file which will be opened
	private String theOpenedFileURI;
	
	// A file chooser
	private JFileChooser fcOpenFile = new JFileChooser();
	
	// The canvas
	private JSVGCanvas canvas = new JSVGCanvas();
	
	public SVGFileViewerPlus() {
		// Usual Swing-specific code
		super("SVG File Viewer Plus");
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		JPanel panel = new JPanel();
		JPanel p = new JPanel();
		
		btnOpenFile = new JButton("Open File...");
		btnSaveFile = new JButton("Save File...");
		btnOpenFile.addActionListener(this);
		btnSaveFile.addActionListener(this);
		
		p.add(btnOpenFile);
		p.add(btnSaveFile);
		
		panel.setLayout(new BorderLayout());
		panel.add("North", p);
		
		// Setting the size of the canvas
		canvas.setMySize(new Dimension(800, 450));
		
		// Preparing the components for displaying
		panel.add("Center", canvas);
		this.setContentPane(panel);
		this.pack();
		this.setBounds(150, 150, this.getWidth(), this.getHeight());
	}
	
	public static void main(String[] args) {
		SVGFileViewerPlus viewer = new SVGFileViewerPlus();
		viewer.setVisible(true);
	}
	
	public void actionPerformed(ActionEvent ae) {
		Object source = ae.getSource();
		if (source == btnOpenFile) {
			int returnVal = fcOpenFile.showOpenDialog(this);
			try {
		        if (returnVal == JFileChooser.APPROVE_OPTION) {
		            File file = fcOpenFile.getSelectedFile();
		            theOpenedFileURI = file.toURL().toString();
		            canvas.setURI(theOpenedFileURI);
		        }
			} catch (IOException ioe) {
				System.err.print(ioe.toString());
			}
		}
		if (source == btnSaveFile) {
			int returnVal = fcOpenFile.showSaveDialog(this);
			try {
		        if (returnVal == JFileChooser.APPROVE_OPTION) {
		            File file = fcOpenFile.getSelectedFile();
		    		OutputStream ostream = new FileOutputStream(file.getPath());
		    		Transcoder t = new PNGTranscoder();
		    		
		    		// Creating input and output objects
					TranscoderInput input = new TranscoderInput(theOpenedFileURI);
					TranscoderOutput output = new TranscoderOutput(ostream);
					
					// Transcoding
					t.transcode(input, output);
					
					ostream.flush();
					ostream.close();	
		        }
			} 
			catch (TranscoderException te) {
				System.err.println("Transcoder problem: " + te.toString());
			}
			catch (IOException ioe) {
				System.err.print(ioe.toString());
			}
		}
	}
}
